@@ -10,7 +10,7 @@ use DateTime::Infinite;
 require Exporter;
 our @ISA = qw(Exporter);
 
-our @EXPORT_OK = qw(format_date parse_date parse_european_date);
+our @EXPORT_OK = qw(format_date parse_date parse_european_date parse_epoch);
 
 our %EXPORT_TAGS =
 (
@@ -18,7 +18,7 @@ our %EXPORT_TAGS =
   all => \@EXPORT_OK
 );
 
-our $VERSION = '0.522';
+our $VERSION = '0.53';
 
 our $TZ = 'floating';
 our $Debug = 0;
@@ -37,7 +37,7 @@ sub time_zone
 sub european_dates
 {
   my($class) = shift;
-  
+
   if(@_)
   {
     if(defined $_[0])
@@ -61,7 +61,7 @@ sub init_european_dates
   {
     return 1;
   }
-  
+
   return 0;
 }
 
@@ -82,6 +82,8 @@ sub parse_date
 
   $Error = undef;
 
+  no warnings 'uninitialized';
+
   if(ref $arg && $arg->isa('DateTime'))
   {
     if(@_ > 1)
@@ -153,12 +155,17 @@ sub parse_date
     # Right now
     return DateTime->now(time_zone => $time_zone);
   }
-  elsif($arg =~ /^(-?\d{9,10})(?:\.(\d{0,9}))?$/)
+  elsif($arg =~ /^(?: (-?\d+)(?:\.(\d{0,9}))? | (-?\d*)\.(\d{1,9}) )$/x)
   {
-    # In Unix time format (guessing)
-    $date = DateTime->from_epoch(epoch => $1, time_zone => $time_zone);
+    my $epoch = defined $1 ? $1 : $3;
+    my $fsecs = defined $2 ? $2 : $4;
 
-    if(my $fsecs = $2)
+    $epoch = 0  if($epoch eq '-');
+
+    # In Unix time format (guessing)
+    $date = DateTime->from_epoch(epoch => $epoch || 0, time_zone => $time_zone);
+
+    if($fsecs)
     {
       my $len = length $fsecs;
 
@@ -183,7 +190,6 @@ sub parse_date
     $date->minute(0);
     $date->second(0);
   }
-
   elsif($arg =~ /^(-)?infinity$/i)
   {
     if($1)
@@ -210,6 +216,61 @@ sub parse_date
   return $date;
 }
 
+sub parse_epoch
+{
+  my($arg, $time_zone) = @_;
+
+  $time_zone ||= $TZ;
+
+  $Error = undef;
+
+  my $date;
+
+  no warnings 'uninitialized';
+
+  if($arg =~ /^(?: (-?\d+)(?:\.(\d{0,9}))? | (-?\d*)\.(\d{1,9}) )$/x)
+  {
+    my $epoch = defined $1 ? $1 : $3;
+    my $fsecs = defined $2 ? $2 : $4;
+
+    $epoch = 0  if($epoch eq '-');
+
+    # In Unix time format (guessing)
+    $date = DateTime->from_epoch(epoch => $epoch || 0, time_zone => $time_zone);
+
+    if($fsecs)
+    {
+      my $len = length $fsecs;
+
+      if($len < 9)
+      {
+        $fsecs .= ('0' x (9 - length $fsecs));
+      }
+      elsif($len > 9)
+      {
+        $fsecs = substr($fsecs, 0, 9);
+      }
+
+      $date->set(nanosecond => $fsecs);
+    }
+
+    return $date;
+  }
+  else
+  {
+    return parse_date(@_);
+  }
+
+  unless($date)
+  {
+    $Error = "Could not parse epoch: $arg" .
+             (($Error) ? " - $Error" : '');
+    return undef;
+  }
+
+  return $date;
+}
+
 sub format_date
 {
   my($date, @formats) = @_;
@@ -386,6 +447,7 @@ will cause the following function names to be imported:
 
     format_date()
     parse_date()
+    parse_epoch()
     parse_european_date()
 
 =head1 CLASS METHODS
@@ -705,10 +767,19 @@ Positive or negative infinity.  Case insensitive.
 
 =item [-]dddddddddd[.nnnnnnnnn] seconds)
 
-A 9 or 10-digit positive or negative number with optional fractional seconds is interpreted as seconds since the Unix epoch.  Fractional seconds take a maximum of 9 digits, but fewer are also acceptable.
+A positive or negative number with optional fractional seconds is interpreted as seconds since the Unix epoch.  Fractional seconds take a maximum of 9 digits, but fewer are also acceptable.
 
 =back
 
+=item B<parse_epoch TEXT [, TIMEZONE]>
+
+This function is the same as L<parse_date|/parse_date> except that it prefers Unix epoch values in cases where this format conflicts with another.  Example:
+
+    $arg = '19991231';
+
+    $dt = parse_date($arg);  # Dec 31, 1999
+    $dt = parse_epoch($arg); # Aug 20, 1970
+
 =back
 
 =head1 SEE ALSO
